@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2023 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -279,6 +279,8 @@
 #define PING_ICMP 1
 #define PING_UDP 2
 #define PING_TCP 3
+#define PING_SNMP 4
+#define PING_TCP_CLOSED 5
 
 #define HOST_UNKNOWN 0
 #define HOST_DOWN 1
